@@ -1,7 +1,7 @@
 package Bencher::Scenario::LevenshteinModules;
 
-our $DATE = '2016-01-14'; # DATE
-our $VERSION = '0.09'; # VERSION
+our $DATE = '2016-01-20'; # DATE
+our $VERSION = '0.10'; # VERSION
 
 use 5.010001;
 use strict;
@@ -54,7 +54,7 @@ Bencher::Scenario::LevenshteinModules - Benchmark various modules calculating th
 
 =head1 VERSION
 
-This document describes version 0.09 of Bencher::Scenario::LevenshteinModules (from Perl distribution Bencher-Scenario-LevenshteinModules), released on 2016-01-14.
+This document describes version 0.10 of Bencher::Scenario::LevenshteinModules (from Perl distribution Bencher-Scenario-LevenshteinModules), released on 2016-01-20.
 
 =head1 SYNOPSIS
 
@@ -82,7 +82,7 @@ L<Text::LevenshteinXS> 0.03
 
 =over
 
-=item * PERLANCAR::Text::Levenshtein::editdist (perl_code)
+=item * PERLANCAR::Text::Levenshtein::editdist (perl_code) [no_unicode_support]
 
 Function call template:
 
@@ -106,7 +106,7 @@ Function call template:
 
 
 
-=item * Text::LevenshteinXS::distance (perl_code)
+=item * Text::LevenshteinXS::distance (perl_code) [no_unicode_support]
 
 Function call template:
 
@@ -114,56 +114,68 @@ Function call template:
 
 
 
+=back
+
+=head1 BENCHMARK DATASETS
+
+=over
+
+=item * a
+
+=item * foo
+
+=item * program
+
+=item * reve [unicode]
+
+=item * euro [unicode]
+
 =back
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
 
-Benchmark with default option:
+Benchmark with default options (C<< bencher -m LevenshteinModules >>):
 
- +-----+----------------------------------------+---------+-------------+------------+---------+---------+
- | seq | participant                            | dataset | rate        | time       | errors  | samples |
- +-----+----------------------------------------+---------+-------------+------------+---------+---------+
- | 5   | Text::Levenshtein::fastdistance        | program | 18717       | 53.4274μs  | 0       | 20      |
- | 2   | PERLANCAR::Text::Levenshtein::editdist | program | 3e+04       | 33.3μs     | 1.1e-08 | 31      |
- | 6   | Text::Levenshtein::fastdistance        | reve    | 4.341e+04   | 23.04μs    | 4.9e-09 | 37      |
- | 7   | Text::Levenshtein::fastdistance        | euro    | 5.024e+04   | 19.9μs     | 6e-09   | 25      |
- | 4   | Text::Levenshtein::fastdistance        | foo     | 8.77e+04    | 11.4μs     | 9.8e-09 | 21      |
- | 1   | PERLANCAR::Text::Levenshtein::editdist | foo     | 1.17e+05    | 8.58μs     | 1e-08   | 35      |
- | 3   | Text::Levenshtein::fastdistance        | a       | 2.82e+05    | 3.54μs     | 5e-09   | 20      |
- | 0   | PERLANCAR::Text::Levenshtein::editdist | a       | 451726      | 2.21373μs  | 0       | 20      |
- | 10  | Text::Levenshtein::XS::distance        | program | 648688      | 1.54157μs  | 0       | 20      |
- | 11  | Text::Levenshtein::XS::distance        | reve    | 845922      | 1.18214μs  | 0       | 20      |
- | 12  | Text::Levenshtein::XS::distance        | euro    | 912027      | 1.09646μs  | 0       | 20      |
- | 9   | Text::Levenshtein::XS::distance        | foo     | 1.0183e+06  | 0.982025μs | 0       | 31      |
- | 8   | Text::Levenshtein::XS::distance        | a       | 1.28859e+06 | 0.776044μs | 0       | 20      |
- | 15  | Text::LevenshteinXS::distance          | program | 4.21e+06    | 0.237μs    | 1e-10   | 20      |
- | 14  | Text::LevenshteinXS::distance          | foo     | 9.42933e+06 | 0.106052μs | 0       | 20      |
- | 13  | Text::LevenshteinXS::distance          | a       | 1.17e+07    | 0.0854μs   | 5.2e-11 | 20      |
- +-----+----------------------------------------+---------+-------------+------------+---------+---------+
+ +----------------------------------------+---------+------------+-----------+---------+---------+
+ | participant                            | dataset | rate (/s)  | time (μs) | errors  | samples |
+ +----------------------------------------+---------+------------+-----------+---------+---------+
+ | Text::Levenshtein::fastdistance        | program | 1.19e+04   | 84.2      | 1.1e-07 | 20      |
+ | PERLANCAR::Text::Levenshtein::editdist | program | 1.83e+04   | 54.7      | 2.5e-08 | 22      |
+ | Text::Levenshtein::fastdistance        | reve    | 2.7e+04    | 37.1      | 5.3e-08 | 20      |
+ | Text::Levenshtein::fastdistance        | euro    | 29238.7    | 34.2012   | 4.6e-11 | 20      |
+ | Text::Levenshtein::fastdistance        | foo     | 5.46e+04   | 18.3      | 6.4e-09 | 22      |
+ | PERLANCAR::Text::Levenshtein::editdist | foo     | 7.17e+04   | 13.9      | 5.8e-09 | 26      |
+ | Text::Levenshtein::fastdistance        | a       | 1.58e+05   | 6.34      | 2.8e-09 | 28      |
+ | PERLANCAR::Text::Levenshtein::editdist | a       | 2.77e+05   | 3.62      | 6.7e-09 | 20      |
+ | Text::Levenshtein::XS::distance        | program | 4.5e+05    | 2.22      | 3.9e-09 | 23      |
+ | Text::Levenshtein::XS::distance        | reve    | 5.58e+05   | 1.79      | 7.8e-10 | 23      |
+ | Text::Levenshtein::XS::distance        | euro    | 5.9688e+05 | 1.6754    | 2.3e-11 | 20      |
+ | Text::Levenshtein::XS::distance        | foo     | 6.5e+05    | 1.5       | 6.5e-09 | 21      |
+ | Text::Levenshtein::XS::distance        | a       | 7.986e+05  | 1.252     | 3.8e-10 | 24      |
+ | Text::LevenshteinXS::distance          | program | 2.9e+06    | 0.345     | 2.1e-10 | 20      |
+ | Text::LevenshteinXS::distance          | foo     | 5.93e+06   | 0.169     | 4.1e-10 | 21      |
+ | Text::LevenshteinXS::distance          | a       | 7.39e+06   | 0.135     | 1.6e-10 | 20      |
+ +----------------------------------------+---------+------------+-----------+---------+---------+
 
 
-Benchmark module startup overhead:
+Benchmark module startup overhead (C<< bencher -m LevenshteinModules --module-startup >>):
 
- +-----+------------------------------+--------+-------------------+---------+---------+
- | seq | participant                  | time   | mod_overhead_time | errors  | samples |
- +-----+------------------------------+--------+-------------------+---------+---------+
- | 4   | Text::LevenshteinXS          | 8.54ms | 6.09ms            | 1.5e-05 | 20      |
- | 2   | Text::Levenshtein            | 7.05ms | 4.6ms             | 1.6e-05 | 20      |
- | 3   | Text::Levenshtein::XS        | 4.89ms | 2.44ms            | 1.4e-05 | 20      |
- | 1   | PERLANCAR::Text::Levenshtein | 2.71ms | 0.259ms           | 8.1e-06 | 20      |
- | 0   | perl -e1 (baseline)          | 2.4ms  | 0ms               | 9e-06   | 20      |
- +-----+------------------------------+--------+-------------------+---------+---------+
+ +------------------------------+-----------+------------------------+---------+---------+
+ | participant                  | time (ms) | mod_overhead_time (ms) | errors  | samples |
+ +------------------------------+-----------+------------------------+---------+---------+
+ | Text::LevenshteinXS          | 15        | 10.4                   | 0.00012 | 23      |
+ | Text::Levenshtein            | 11.8      | 7.2                    | 2.3e-05 | 20      |
+ | Text::Levenshtein::XS        | 8.53      | 3.93                   | 2.5e-05 | 20      |
+ | PERLANCAR::Text::Levenshtein | 4.7       | 0.100000000000001      | 1.5e-05 | 20      |
+ | perl -e1 (baseline)          | 4.6       | 0                      | 2.2e-05 | 20      |
+ +------------------------------+-----------+------------------------+---------+---------+
 
 =head1 DESCRIPTION
 
 Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
 
-=head1 SEE ALSO
-
-L<Bencher::Scenario::DamerauLevenshteinModules>
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Bencher-Scenario-LevenshteinModules>.
@@ -180,6 +192,10 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Bencher::Scenario::DamerauLevenshteinModules>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
